@@ -5,7 +5,7 @@ from scipy.stats import gmean, hmean
 from scipy.fft import fftn
 from numpy import (
     ndarray, concatenate, argmax, array,
-    zeros, mean, max, min, sum, pad
+    zeros, mean, max, min, sum, pad, norm
 )
 
 from ffast.poincare.token import Token
@@ -45,9 +45,15 @@ class Tokens:
 
     def semantics(self) -> List[ndarray]:
         return list(map(lambda token:token.semantics, self.tokens))
+    
+    def weights(self) -> List[float]:
+        return list(map(self.__weight,self.tokens))
+
+    def skip_common_words(self) -> "Tokens":
+        return Tokens(list(filter(lambda token:self.__weight(token)==0),self.tokens),pad_token_id=self.pad_token_id)
 
     def skip_unknowns(self) -> "Tokens":
-        return Tokens(list(filter(lambda token:token.morphology != Poincare.UNKNOWN.value,self.tokens)))
+        return Tokens(list(filter(lambda token:token.morphology != Poincare.UNKNOWN.value,self.tokens)),pad_token_id=self.pad_token_id)
 
     def most_similar(self, others:List["Tokens"]) -> "Tokens":
         others_vectors = array(list(map(lambda other:other.vector, others)))
@@ -107,4 +113,9 @@ class Tokens:
             Tokens.__embed_token_phonetics(token),
             Tokens.__embed_token_semantics(token),
         ])    
-    
\ No newline at end of file
+    
+    @staticmethod
+    def __weight(token:Token,minimum_weight:float = 0.,maximum_weight:float = 1.,scaling_factor:float = 10.) -> float:
+        approximation_of_token_frequency = .5 - norm(token.semantics)
+        approximation_of_token_frequency *= scaling_factor
+        return min(maximum_weight,max(minimum_weight,approximation_of_token_frequency))
\ No newline at end of file
